# coding: utf-8

"""
    Accounting API


    The version of the OpenAPI document: 7.5.8
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
from urllib.parse import urljoin

import requests_mock

from accounting_sh.accounting import Accounting
from accounting_sh.api.attachments_api import AttachmentsApi


class TestAttachmentsApi(unittest.TestCase):
    """AttachmentsApi unit test stubs"""

    """
    def setUp(self) -> None:
        accounting = Accounting("fake-token")
        self.api = accounting.attachments_api

    def tearDown(self) -> None:
        pass
    """

    @requests_mock.Mocker()
    def test_add_attachment(self, m) -> None:
        """Test case for add_attachment

        Add an attachment
        """
        path = urljoin("https://api.accounting.sh", "/attachments")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.attachments_api.add_attachment(
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_delete_attachment(self, m) -> None:
        """Test case for delete_attachment

        Delete an attachment
        """
        path = urljoin("https://api.accounting.sh", "/attachments/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("DELETE", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.attachments_api.delete_attachment(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_get_attachment(self, m) -> None:
        """Test case for get_attachment

        Get an attachment
        """
        path = urljoin("https://api.accounting.sh", "/attachments/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.attachments_api.get_attachment(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_attachments(self, m) -> None:
        """Test case for list_attachments

        List company's attachments
        """
        path = urljoin("https://api.accounting.sh", "/attachments")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.attachments_api.list_attachments(
                "fields_example",
                "page_example",
                "per_page_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_retrieve_attachments(self, m) -> None:
        """Test case for retrieve_attachments

        List company's attachments link to resource
        """
        path = urljoin("https://api.accounting.sh", "/attachments/resource/{resource}")
        path = path.replace("{" + "resource" + "}", "resource_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.attachments_api.retrieve_attachments(
                "resource_example",
                "fields_example",
                "page_example",
                "per_page_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_update_attachment(self, m) -> None:
        """Test case for update_attachment

        Update an attachment
        """
        path = urljoin("https://api.accounting.sh", "/attachments/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("PUT", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.attachments_api.update_attachment(
                "uuid_example",
                {},
            )
            is not None
        )


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Accounting API


    The version of the OpenAPI document: 7.5.8
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
from urllib.parse import urljoin

import requests_mock

from accounting_sh.accounting import Accounting
from accounting_sh.api.logs_api import LogsApi


class TestLogsApi(unittest.TestCase):
    """LogsApi unit test stubs"""

    """
    def setUp(self) -> None:
        accounting = Accounting("fake-token")
        self.api = accounting.logs_api

    def tearDown(self) -> None:
        pass
    """

    @requests_mock.Mocker()
    def test_logs(self, m) -> None:
        """Test case for logs

        List company's logs
        """
        path = urljoin("https://api.accounting.sh", "/logs")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.logs_api.logs(
                "fields_example",
                "page_example",
                "per_page_example",
                "channel_example",
                "level_example",
                "resource_example",
                "before_example",
                "after_example",
                "format_example",
            )
            is not None
        )


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Accounting API


    The version of the OpenAPI document: 7.5.8
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from json import dumps
from typing import Any, Dict, List, Optional, Tuple, Union
from urllib.parse import urlencode

from typing_extensions import Annotated


class CountriesApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, accounting) -> None:
        self.accounting = accounting

    def get_translated_countries(self, lang: str, **kwargs) -> Any | None:
        """Get translated list of countries


        :param lang: The target language (required)
        :type lang: str
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/countries/{lang}"
        query_params = {}
        kwargs = kwargs | {"files": {}, "data": {}, "json": {}}

        if lang is not None:
            path = path.replace("{" + "lang" + "}", lang)

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="GET", path=path, **kwargs)



# coding: utf-8

"""
    Accounting API


    The version of the OpenAPI document: 7.5.8
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
from urllib.parse import urljoin

import requests_mock

from accounting_sh.accounting import Accounting
from accounting_sh.api.notification_api import NotificationApi


class TestNotificationApi(unittest.TestCase):
    """NotificationApi unit test stubs"""

    """
    def setUp(self) -> None:
        accounting = Accounting("fake-token")
        self.api = accounting.notification_api

    def tearDown(self) -> None:
        pass
    """

    @requests_mock.Mocker()
    def test_list_notification_preferences(self, m) -> None:
        """Test case for list_notification_preferences

        List notification preferences
        """
        path = urljoin(
            "https://api.accounting.sh", "/notifications/preferences/{notification}"
        )
        path = path.replace("{" + "notification" + "}", "notification_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.notification_api.list_notification_preferences(
                "notification_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_notifications(self, m) -> None:
        """Test case for list_notifications

        List company's notifications
        """
        path = urljoin("https://api.accounting.sh", "/notifications")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.notification_api.list_notifications(
                "fields_example",
                "page_example",
                "per_page_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_send_notification(self, m) -> None:
        """Test case for send_notification

        Send a notification
        """
        path = urljoin("https://api.accounting.sh", "/notifications/send")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.notification_api.send_notification(
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_update_notification_preferences(self, m) -> None:
        """Test case for update_notification_preferences

        Update notification preferences
        """
        path = urljoin(
            "https://api.accounting.sh", "/notifications/preferences/{notification}"
        )
        path = path.replace("{" + "notification" + "}", "notification_example")
        m.request("PUT", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.notification_api.update_notification_preferences(
                "notification_example",
                {},
            )
            is not None
        )


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Accounting API


    The version of the OpenAPI document: 7.5.8
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
from urllib.parse import urljoin

import requests_mock

from accounting_sh.accounting import Accounting
from accounting_sh.api.payments_api import PaymentsApi


class TestPaymentsApi(unittest.TestCase):
    """PaymentsApi unit test stubs"""

    """
    def setUp(self) -> None:
        accounting = Accounting("fake-token")
        self.api = accounting.payments_api

    def tearDown(self) -> None:
        pass
    """

    @requests_mock.Mocker()
    def test_add_payment(self, m) -> None:
        """Test case for add_payment

        Add a payment
        """
        path = urljoin("https://api.accounting.sh", "/expenses/payments")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.payments_api.add_payment(
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_delete_payment(self, m) -> None:
        """Test case for delete_payment

        Delete a payment
        """
        path = urljoin("https://api.accounting.sh", "/expenses/payments/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("DELETE", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.payments_api.delete_payment(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_get_payment(self, m) -> None:
        """Test case for get_payment

        Get a payment
        """
        path = urljoin("https://api.accounting.sh", "/expenses/payments/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.payments_api.get_payment(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_payments(self, m) -> None:
        """Test case for list_payments

        List company's payments
        """
        path = urljoin("https://api.accounting.sh", "/expenses/payments")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.payments_api.list_payments(
                "fields_example",
                "page_example",
                "per_page_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_update_payment(self, m) -> None:
        """Test case for update_payment

        Update a payment
        """
        path = urljoin("https://api.accounting.sh", "/expenses/payments/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("PUT", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.payments_api.update_payment(
                "uuid_example",
                {},
            )
            is not None
        )


if __name__ == "__main__":
    unittest.main()
